@@ -21,7 +21,11 @@
 #include "columnar/columnar_tableam.h"
 
 
+#if PG_VERSION_NUM >= PG_VERSION_18
+PG_MODULE_MAGIC_EXT(.name = "citus_columnar", .version = "14.0.0");
+#else
 PG_MODULE_MAGIC;
+#endif
 
 void _PG_init(void);
 
