@@ -50,7 +50,7 @@
 
 #define DEFAULT_STATISTICS_TARGET -1
 #define ALTER_INDEX_COLUMN_SET_STATS_COMMAND \
-	"ALTER INDEX %s ALTER COLUMN %d SET STATISTICS %d"
+		"ALTER INDEX %s ALTER COLUMN %d SET STATISTICS %d"
 
 static char * GenerateAlterIndexColumnSetStatsCommand(char *indexNameWithSchema,
 													  int16 attnum,
@@ -69,7 +69,15 @@ PreprocessCreateStatisticsStmt(Node *node, const char *queryString,
 {
 	CreateStatsStmt *stmt = castNode(CreateStatsStmt, node);
 
-	RangeVar *relation = (RangeVar *) linitial(stmt->relations);
+	Node *relationNode = (Node *) linitial(stmt->relations);
+
+	if (!IsA(relationNode, RangeVar))
+	{
+		return NIL;
+	}
+
+	RangeVar *relation = (RangeVar *) relationNode;
+
 	Oid relationId = RangeVarGetRelid(relation, ShareUpdateExclusiveLock, false);
 
 	if (!IsCitusTable(relationId) || !ShouldPropagate())
