@@ -475,8 +475,8 @@ FindAvailableConnection(dlist_head *connections, uint32 flags)
 		if (flags & OUTSIDE_TRANSACTION)
 		{
 			/* don't return connections that are used in transactions */
-			if (connection->remoteTransaction.transactionState !=
-				REMOTE_TRANS_NOT_STARTED)
+			if (connection->
+				remoteTransaction.transactionState != REMOTE_TRANS_NOT_STARTED)
 			{
 				continue;
 			}
