@@ -939,8 +939,8 @@ TryDropDatabaseOutsideTransaction(char *databaseName, char *nodeName, int nodePo
 		 * because we don't want to open a transaction block on remote nodes as DROP
 		 * DATABASE commands cannot be run inside a transaction block.
 		 */
-		if (ExecuteOptionalRemoteCommand(connection, commandString, NULL) !=
-			RESPONSE_OKAY)
+		if (ExecuteOptionalRemoteCommand(
+				connection, commandString, NULL) != RESPONSE_OKAY)
 		{
 			executeCommand = false;
 			break;
