@@ -13,6 +13,7 @@
 #include "postgres.h"
 
 #include "funcapi.h"
+#include "miscadmin.h"
 
 #include "access/htup_details.h"
 #include "access/xact.h"
@@ -28,6 +29,7 @@
 #include "optimizer/plancat.h"
 #include "optimizer/planmain.h"
 #include "optimizer/planner.h"
+#include "parser/parse_relation.h"
 #include "parser/parse_type.h"
 #include "parser/parsetree.h"
 #include "utils/builtins.h"
@@ -35,6 +37,7 @@
 #include "utils/lsyscache.h"
 #include "utils/memutils.h"
 #include "utils/syscache.h"
+#include "utils/typcache.h"
 
 #include "pg_version_constants.h"
 
@@ -70,10 +73,6 @@
 #include "distributed/version_compat.h"
 #include "distributed/worker_shard_visibility.h"
 
-#if PG_VERSION_NUM >= PG_VERSION_16
-#include "parser/parse_relation.h"
-#endif
-
 
 static List *plannerRestrictionContextList = NIL;
 int MultiTaskQueryLogLevel = CITUS_LOG_LEVEL_OFF; /* multi-task query log level */
@@ -84,8 +83,9 @@ int PlannerLevel = 0;
 
 static bool ListContainsDistributedTableRTE(List *rangeTableList,
 											bool *maybeHasForeignDistributedTable);
-static PlannedStmt * CreateDistributedPlannedStmt(
-	DistributedPlanningContext *planContext);
+static bool PlanContainsDistributedSubPlanRTE(List *subPlanList);
+static PlannedStmt * CreateDistributedPlannedStmt(DistributedPlanningContext *
+												  planContext);
 static PlannedStmt * InlineCtesAndCreateDistributedPlannedStmt(uint64 planId,
 															   DistributedPlanningContext
 															   *planContext);
@@ -124,12 +124,14 @@ static void AdjustReadIntermediateResultsCostInternal(RelOptInfo *relOptInfo,
 													  Const *resultFormatConst);
 static List * OuterPlanParamsList(PlannerInfo *root);
 static List * CopyPlanParamList(List *originalPlanParamList);
-static PlannerRestrictionContext * CreateAndPushPlannerRestrictionContext(
-	FastPathRestrictionContext *fastPathContext);
+static void CreateAndPushPlannerRestrictionContext(DistributedPlanningContext *
+												   planContext,
+												   FastPathRestrictionContext *
+												   fastPathContext);
 static PlannerRestrictionContext * CurrentPlannerRestrictionContext(void);
 static void PopPlannerRestrictionContext(void);
-static void ResetPlannerRestrictionContext(
-	PlannerRestrictionContext *plannerRestrictionContext);
+static void ResetPlannerRestrictionContext(PlannerRestrictionContext *
+										   plannerRestrictionContext);
 static PlannedStmt * PlanFastPathDistributedStmt(DistributedPlanningContext *planContext);
 static PlannedStmt * PlanDistributedStmt(DistributedPlanningContext *planContext,
 										 int rteIdCounter);
@@ -144,6 +146,9 @@ static void ConcatenateRTablesAndPerminfos(PlannedStmt *mainPlan,
 static bool CheckPostPlanDistribution(DistributedPlanningContext *planContext,
 									  bool isDistributedQuery,
 									  List *rangeTableList);
+#if PG_VERSION_NUM >= PG_VERSION_18
+static int DisableSelfJoinElimination(void);
+#endif
 
 /* Distributed planner hook */
 PlannedStmt *
@@ -155,6 +160,9 @@ distributed_planner(Query *parse,
 	bool needsDistributedPlanning = false;
 	bool fastPathRouterQuery = false;
 	FastPathRestrictionContext fastPathContext = { 0 };
+#if PG_VERSION_NUM >= PG_VERSION_18
+	int saveNestLevel = -1;
+#endif
 
 	List *rangeTableList = ExtractRangeTableEntryList(parse);
 
@@ -218,6 +226,10 @@ distributed_planner(Query *parse,
 			bool setPartitionedTablesInherited = false;
 			AdjustPartitioningForDistributedPlanning(rangeTableList,
 													 setPartitionedTablesInherited);
+
+#if PG_VERSION_NUM >= PG_VERSION_18
+			saveNestLevel = DisableSelfJoinElimination();
+#endif
 		}
 	}
 
@@ -234,9 +246,9 @@ distributed_planner(Query *parse,
 	 */
 	HideCitusDependentObjectsOnQueriesOfPgMetaTables((Node *) parse, NULL);
 
-	/* create a restriction context and put it at the end of context list */
-	planContext.plannerRestrictionContext = CreateAndPushPlannerRestrictionContext(
-		&fastPathContext);
+	/* create a restriction context and put it at the end of our plan context's context list */
+	CreateAndPushPlannerRestrictionContext(&planContext,
+										   &fastPathContext);
 
 	/*
 	 * We keep track of how many times we've recursed into the planner, primarily
@@ -264,6 +276,16 @@ distributed_planner(Query *parse,
 			planContext.plan = standard_planner(planContext.query, NULL,
 												planContext.cursorOptions,
 												planContext.boundParams);
+#if PG_VERSION_NUM >= PG_VERSION_18
+			if (needsDistributedPlanning)
+			{
+				Assert(saveNestLevel > 0);
+				AtEOXact_GUC(true, saveNestLevel);
+			}
+
+			/* Pop the plan context from the current restriction context */
+			planContext.plannerRestrictionContext->planContext = NULL;
+#endif
 			needsDistributedPlanning = CheckPostPlanDistribution(&planContext,
 																 needsDistributedPlanning,
 																 rangeTableList);
@@ -412,6 +434,49 @@ ListContainsDistributedTableRTE(List *rangeTableList,
 }
 
 
+/*
+ * PlanContainsDistributedSubPlanRTE checks whether any of the subplans in the given
+ * subPlanList is a Read Intermediate Result function scan.
+ *
+ * It is used by the check after standard_planner() to determine whether the plan
+ * still requires distributed planning; in addition to checking the range table for
+ * distributed tables, we also need to check whether there are any subplans that
+ * read intermediate results, which indicates a distributed subplan and therefore
+ * that distributed planning is required.
+ */
+static bool
+PlanContainsDistributedSubPlanRTE(List *subPlanList)
+{
+	ListCell *subPlanCell = NULL;
+
+	foreach(subPlanCell, subPlanList)
+	{
+		Node *planRoot = (Node *) lfirst(subPlanCell);
+
+		if (!IsA(planRoot, FunctionScan))
+		{
+			continue;
+		}
+
+		List *functionList = ((FunctionScan *) planRoot)->functions;
+
+		if (functionList == NIL)
+		{
+			continue;
+		}
+
+		RangeTblFunction *rangeTblfunction = (RangeTblFunction *) linitial(functionList);
+
+		if (IsReadIntermediateResultFunction(rangeTblfunction->funcexpr))
+		{
+			return true;
+		}
+	}
+
+	return false;
+}
+
+
 /*
  * AssignRTEIdentities function modifies query tree by adding RTE identities to the
  * RTE_RELATIONs.
@@ -1487,7 +1552,6 @@ static void
 ConcatenateRTablesAndPerminfos(PlannedStmt *mainPlan, PlannedStmt *concatPlan)
 {
 	mainPlan->rtable = list_concat(mainPlan->rtable, concatPlan->rtable);
-#if PG_VERSION_NUM >= PG_VERSION_16
 
 	/*
 	 * concatPlan's range table list is concatenated to mainPlan's range table list
@@ -1509,7 +1573,6 @@ ConcatenateRTablesAndPerminfos(PlannedStmt *mainPlan, PlannedStmt *concatPlan)
 
 	/* finally, concatenate perminfos as well */
 	mainPlan->permInfos = list_concat(mainPlan->permInfos, concatPlan->permInfos);
-#endif
 }
 
 
@@ -1705,6 +1768,57 @@ BlessRecordExpression(Expr *expr)
 
 		typeMod = rowTupleDesc->tdtypmod;
 	}
+
+	/*
+	 * Record aggregates need blessed typmods to parse worker results.
+	 * For PG18, AGG_MATCH_RECORD allows MIN/MAX on composite types.
+	 *
+	 * Limitation: For multi-argument aggregates returning RECORD, we only
+	 * bless the first argument's type. This works for MIN/MAX (single-argument)
+	 * but may not handle custom multi-argument aggregates correctly.
+	 */
+	else if (IsA(expr, Aggref))
+	{
+		Aggref *aggref = (Aggref *) expr;
+
+		if (aggref->aggtype == RECORDOID && list_length(aggref->args) > 0)
+		{
+			if (list_length(aggref->args) > 1)
+			{
+				ereport(DEBUG2,
+						(errmsg(
+							 "blessing record aggregate with %d arguments, using first",
+							 list_length(aggref->args))));
+			}
+
+			TargetEntry *argTle = (TargetEntry *) linitial(aggref->args);
+			Oid argTypeId = exprType((Node *) argTle->expr);
+			int32 argTypeMod = exprTypmod((Node *) argTle->expr);
+
+			if (argTypeId == RECORDOID)
+			{
+				argTypeMod = BlessRecordExpression((Expr *) argTle->expr);
+			}
+
+			/* Use a RECORD TupleDesc derived from a named rowtype argument. */
+			if (type_is_rowtype(argTypeId))
+			{
+				TupleDesc argTupleDesc =
+					lookup_rowtype_tupdesc_copy(argTypeId, argTypeMod);
+
+				argTupleDesc->tdtypeid = RECORDOID;
+				argTupleDesc->tdtypmod = -1;
+				BlessTupleDesc(argTupleDesc);
+				typeMod = argTupleDesc->tdtypmod;
+			}
+
+			/*
+			 * If argTypeId is not a rowtype, we leave typeMod as -1.
+			 * This should not happen in practice since AGG_MATCH_RECORD
+			 * only matches rowtypes, but it's safe to fall through.
+			 */
+		}
+	}
 	else if (IsA(expr, ArrayExpr))
 	{
 		/*
@@ -1995,18 +2109,6 @@ multi_relation_restriction_hook(PlannerInfo *root, RelOptInfo *relOptInfo,
 	{
 		cacheEntry = GetCitusTableCacheEntry(rte->relid);
 
-#if PG_VERSION_NUM == PG_VERSION_15
-
-		/*
-		 * Postgres 15.0 had a bug regarding inherited statistics expressions,
-		 * which is fixed in 15.1 via Postgres commit
-		 * 1f1865e9083625239769c26f68b9c2861b8d4b1c.
-		 *
-		 * Hence, we only set this value on exactly PG15.0
-		 */
-		relOptInfo->statlist = NIL;
-#endif
-
 		relationRestrictionContext->allReferenceTables &=
 			IsCitusTableTypeCacheEntry(cacheEntry, REFERENCE_TABLE);
 	}
@@ -2015,6 +2117,32 @@ multi_relation_restriction_hook(PlannerInfo *root, RelOptInfo *relOptInfo,
 		lappend(relationRestrictionContext->relationRestrictionList, relationRestriction);
 
 	MemoryContextSwitchTo(oldMemoryContext);
+
+#if PG_VERSION_NUM >= PG_VERSION_18
+	if (root->query_level == 1 && plannerRestrictionContext->planContext != NULL)
+	{
+		/* We're at the top query with a distributed context; see if Postgres
+		 * has changed the query tree we passed to it in distributed_planner().
+		 * This check was necessitated by PG commit 1e4351a, becuase in it the
+		 * planner modfies a copy of the passed in query tree with the consequence
+		 * that changes are not reflected back to the caller of standard_planner().
+		 */
+		Query *query = plannerRestrictionContext->planContext->query;
+		if (root->parse != query)
+		{
+			/*
+			 * The Postgres planner has reconstructed the query tree, so the query
+			 * tree our distributed context passed in (to standard_planner() is
+			 * updated to track the new query tree.
+			 */
+			ereport(DEBUG4, (errmsg(
+								 "Detected query reconstruction by Postgres planner, updating "
+								 "planContext to track it")));
+
+			plannerRestrictionContext->planContext->query = root->parse;
+		}
+	}
+#endif
 }
 
 
@@ -2392,11 +2520,13 @@ CopyPlanParamList(List *originalPlanParamList)
  * context with an empty relation restriction context and an empty join and
  * a copy of the given fast path restriction context (if present). Finally,
  * the planner restriction context is inserted to the beginning of the
- * global plannerRestrictionContextList and it is returned.
+ * global plannerRestrictionContextList and, in PG18+, given a reference to
+ * its distributed plan context.
  */
-static PlannerRestrictionContext *
-CreateAndPushPlannerRestrictionContext(
-	FastPathRestrictionContext *fastPathRestrictionContext)
+static void
+CreateAndPushPlannerRestrictionContext(DistributedPlanningContext *planContext,
+									   FastPathRestrictionContext *
+									   fastPathRestrictionContext)
 {
 	PlannerRestrictionContext *plannerRestrictionContext =
 		palloc0(sizeof(PlannerRestrictionContext));
@@ -2433,7 +2563,11 @@ CreateAndPushPlannerRestrictionContext(
 	plannerRestrictionContextList = lcons(plannerRestrictionContext,
 										  plannerRestrictionContextList);
 
-	return plannerRestrictionContext;
+	planContext->plannerRestrictionContext = plannerRestrictionContext;
+
+#if PG_VERSION_NUM >= PG_VERSION_18
+	plannerRestrictionContext->planContext = planContext;
+#endif
 }
 
 
@@ -2494,6 +2628,18 @@ CurrentPlannerRestrictionContext(void)
 static void
 PopPlannerRestrictionContext(void)
 {
+#if PG_VERSION_NUM >= PG_VERSION_18
+
+	/*
+	 * PG18+: Clear the restriction context's planContext pointer; this is done
+	 * by distributed_planner() when popping the context, but in case of error
+	 * during standard_planner() we want to clean up here also.
+	 */
+	PlannerRestrictionContext *plannerRestrictionContext =
+		(PlannerRestrictionContext *) linitial(plannerRestrictionContextList);
+	plannerRestrictionContext->planContext = NULL;
+#endif
+
 	plannerRestrictionContextList = list_delete_first(plannerRestrictionContextList);
 }
 
@@ -2757,20 +2903,26 @@ CheckPostPlanDistribution(DistributedPlanningContext *planContext, bool
 		#endif
 
 		/*
-		 * The WHERE quals have been eliminated by the Postgres planner, possibly by
-		 * an OR clause that was simplified to TRUE. In such cases, we need to check
-		 * if the planned query still requires distributed planning.
+		 * If the WHERE quals have been eliminated by the Postgres planner, possibly
+		 * by an OR clause that was simplified to TRUE, we need to check if the
+		 * planned query still requires distributed planning.
 		 */
 		if (origQuals != NULL && plannedQuals == NULL)
 		{
-			bool planHasDistTable = ListContainsDistributedTableRTE(
+			/* First check if the plan has a distributed table */
+			bool planHasDistribution = ListContainsDistributedTableRTE(
 				planContext->plan->rtable, NULL);
 
+			/* ..or a distributed subplan */
+			planHasDistribution = planHasDistribution ||
+								  PlanContainsDistributedSubPlanRTE(
+				planContext->plan->subplans);
+
 			/*
-			 * If the Postgres plan has a distributed table, we know for sure that
+			 * The plan has a distributed relation, so we know for sure that
 			 * the query requires distributed planning.
 			 */
-			if (planHasDistTable)
+			if (planHasDistribution)
 			{
 				return true;
 			}
@@ -2783,11 +2935,43 @@ CheckPostPlanDistribution(DistributedPlanningContext *planContext, bool
 			List *rtesPostPlan = ExtractRangeTableEntryList(plannedQuery);
 			if (list_length(rtesPostPlan) < list_length(rangeTableList))
 			{
-				isDistributedQuery = ListContainsDistributedTableRTE(
+				bool hasDistTable = ListContainsDistributedTableRTE(
 					rtesPostPlan, NULL);
+				if (hasDistTable != isDistributedQuery)
+				{
+					ereport(DEBUG4, (errmsg(
+										 "Plan has flipped from distributed to local "
+										 "after Postgres planning, updating distributed to %u",
+										 hasDistTable)));
+					isDistributedQuery = hasDistTable;
+				}
 			}
 		}
 	}
 
 	return isDistributedQuery;
 }
+
+
+#if PG_VERSION_NUM >= PG_VERSION_18
+
+/*
+ * DisableSelfJoinElimination is used to prevent self join elimination
+ * during distributed query planning to ensure shard queries are correctly
+ * generated. PG18's self join elimination (fc069a3a6) changes the Query
+ * in a way that can cause problems for queries with a mix of Citus and
+ * Postgres tables. Self join elimination is allowed on Postgres tables
+ * only so queries involving shards get the benefit of it.
+ */
+static int
+DisableSelfJoinElimination(void)
+{
+	int NestLevel = NewGUCNestLevel();
+	set_config_option("enable_self_join_elimination", "off",
+					  (superuser() ? PGC_SUSET : PGC_USERSET), PGC_S_SESSION,
+					  GUC_ACTION_LOCAL, true, 0, false);
+	return NestLevel;
+}
+
+
+#endif
