@@ -41,6 +41,7 @@
 static int SourceResultPartitionColumnIndex(Query *mergeQuery,
 											List *sourceTargetList,
 											CitusTableCacheEntry *targetRelation);
+static int FindTargetListEntryWithVarExprAttno(List *targetList, AttrNumber varattno);
 static Var * ValidateAndReturnVarIfSupported(Node *entryExpr);
 static DeferredErrorMessage * DeferErrorIfTargetHasFalseClause(Oid targetRelationId,
 															   PlannerRestrictionContext *
@@ -66,7 +67,8 @@ static DeferredErrorMessage * MergeQualAndTargetListFunctionsSupported(Oid
 																	   Query *query,
 																	   Node *quals,
 																	   List *targetList,
-																	   CmdType commandType);
+																	   CmdType
+																	   commandType);
 
 static DistributedPlan * CreateRouterMergePlan(Oid targetRelationId, Query *originalQuery,
 											   Query *query,
@@ -422,6 +424,9 @@ ErrorIfMergeHasUnsupportedTables(Oid targetRelationId, List *rangeTableList)
 			case RTE_VALUES:
 			case RTE_JOIN:
 			case RTE_CTE:
+#if PG_VERSION_NUM >= PG_VERSION_18
+			case RTE_GROUP:
+#endif
 			{
 				/* Skip them as base table(s) will be checked */
 				continue;
@@ -570,8 +575,8 @@ IsDistributionColumnInMergeSource(Expr *columnExpression, Query *query, bool
 		Var *distributionColumn = DistPartitionKey(relationId);
 
 		/* not all distributed tables have partition column */
-		if (distributionColumn != NULL && column->varattno ==
-			distributionColumn->varattno)
+		if (distributionColumn != NULL &&
+			column->varattno == distributionColumn->varattno)
 		{
 			isDistributionColumn = true;
 		}
@@ -628,6 +633,22 @@ MergeQualAndTargetListFunctionsSupported(Oid resultRelationId, Query *query,
 			}
 		}
 
+		/*
+		 * joinTree->quals, retrieved by GetMergeJoinTree() - either from
+		 * mergeJoinCondition (PG >= 17) or jointree->quals (PG < 17),
+		 * only contains the quals that present in "ON (..)" clause. Action
+		 * quals that can be specified for each specific action, as in
+		 * "WHEN <match condition> AND <action quals> THEN <action>"", are
+		 * saved into "qual" field of the corresponding action's entry in
+		 * mergeActionList, see
+		 * https://github.com/postgres/postgres/blob/e6da68a6e1d60a037b63a9c9ed36e5ef0a996769/src/backend/parser/parse_merge.c#L285-L293.
+		 *
+		 * For this reason, even if TargetEntryChangesValue() could prove that
+		 * an action's quals ensure that the action cannot change the distribution
+		 * key, this is not the case as we don't provide action quals to
+		 * TargetEntryChangesValue(), but just joinTree, which only contains
+		 * the "ON (..)" clause quals.
+		 */
 		if (targetEntryDistributionColumn &&
 			TargetEntryChangesValue(targetEntry, distributionColumn, joinTree))
 		{
@@ -815,11 +836,9 @@ ConvertCteRTEIntoSubquery(Query *mergeQuery, RangeTblEntry *sourceRte)
 	Query *cteQuery = (Query *) copyObject(sourceCte->ctequery);
 
 	sourceRte->rtekind = RTE_SUBQUERY;
-#if PG_VERSION_NUM >= PG_VERSION_16
 
 	/* sanity check - sourceRte was RTE_CTE previously so it should have no perminfo */
 	Assert(sourceRte->perminfoindex == 0);
-#endif
 
 	/*
 	 * As we are delinking the CTE from main query, we have to walk through the
@@ -869,8 +888,6 @@ ConvertRelationRTEIntoSubquery(Query *mergeQuery, RangeTblEntry *sourceRte,
 	/* we copy the input rteRelation to preserve the rteIdentity */
 	RangeTblEntry *newRangeTableEntry = copyObject(sourceRte);
 	sourceResultsQuery->rtable = list_make1(newRangeTableEntry);
-
-#if PG_VERSION_NUM >= PG_VERSION_16
 	sourceResultsQuery->rteperminfos = NIL;
 	if (sourceRte->perminfoindex)
 	{
@@ -882,7 +899,6 @@ ConvertRelationRTEIntoSubquery(Query *mergeQuery, RangeTblEntry *sourceRte,
 		newRangeTableEntry->perminfoindex = 1;
 		sourceResultsQuery->rteperminfos = list_make1(perminfo);
 	}
-#endif
 
 	/* set the FROM expression to the subquery */
 	newRangeTableRef->rtindex = SINGLE_RTE_INDEX;
@@ -909,9 +925,7 @@ ConvertRelationRTEIntoSubquery(Query *mergeQuery, RangeTblEntry *sourceRte,
 
 	/* replace the function with the constructed subquery */
 	sourceRte->rtekind = RTE_SUBQUERY;
-#if PG_VERSION_NUM >= PG_VERSION_16
 	sourceRte->perminfoindex = 0;
-#endif
 	sourceRte->subquery = sourceResultsQuery;
 	sourceRte->inh = false;
 }
@@ -1025,8 +1039,9 @@ DeferErrorIfTargetHasFalseClause(Oid targetRelationId,
 								 PlannerRestrictionContext *plannerRestrictionContext)
 {
 	ListCell *restrictionCell = NULL;
-	foreach(restrictionCell,
-			plannerRestrictionContext->relationRestrictionContext->relationRestrictionList)
+	foreach(
+		restrictionCell,
+		plannerRestrictionContext->relationRestrictionContext->relationRestrictionList)
 	{
 		RelationRestriction *relationRestriction =
 			(RelationRestriction *) lfirst(restrictionCell);
@@ -1058,7 +1073,8 @@ DeferErrorIfTargetHasFalseClause(Oid targetRelationId,
  */
 static DeferredErrorMessage *
 DeferErrorIfRoutableMergeNotSupported(Query *query, List *rangeTableList,
-									  PlannerRestrictionContext *plannerRestrictionContext,
+									  PlannerRestrictionContext *
+									  plannerRestrictionContext,
 									  Oid targetRelationId)
 {
 	List *distTablesList = NIL;
@@ -1095,8 +1111,8 @@ DeferErrorIfRoutableMergeNotSupported(Query *query, List *rangeTableList,
 
 	if (list_length(distTablesList) > 0 && list_length(localTablesList) > 0)
 	{
-		ereport(DEBUG1, (errmsg(
-							 "A mix of distributed and local table, try repartitioning")));
+		ereport(DEBUG1, (errmsg("A mix of distributed and local table, "
+								"try repartitioning")));
 		return DeferredError(ERRCODE_FEATURE_NOT_SUPPORTED,
 							 "A mix of distributed and citus-local table, "
 							 "routable query is not possible", NULL, NULL);
@@ -1411,7 +1427,8 @@ SourceResultPartitionColumnIndex(Query *mergeQuery, List *sourceTargetList,
 	Assert(sourceRepartitionVar);
 
 	int sourceResultRepartitionColumnIndex =
-		DistributionColumnIndex(sourceTargetList, sourceRepartitionVar);
+		FindTargetListEntryWithVarExprAttno(sourceTargetList,
+											sourceRepartitionVar->varattno);
 
 	if (sourceResultRepartitionColumnIndex == -1)
 	{
@@ -1562,6 +1579,33 @@ FetchAndValidateInsertVarIfExists(Oid targetRelationId, Query *query)
 }
 
 
+/*
+ * FindTargetListEntryWithVarExprAttno finds the index of the target
+ * entry whose expr is a Var that points to input varattno.
+ *
+ * If no such target entry is found, it returns -1.
+ */
+static int
+FindTargetListEntryWithVarExprAttno(List *targetList, AttrNumber varattno)
+{
+	int targetEntryIndex = 0;
+
+	TargetEntry *targetEntry = NULL;
+	foreach_declared_ptr(targetEntry, targetList)
+	{
+		if (IsA(targetEntry->expr, Var) &&
+			((Var *) targetEntry->expr)->varattno == varattno)
+		{
+			return targetEntryIndex;
+		}
+
+		targetEntryIndex++;
+	}
+
+	return -1;
+}
+
+
 /*
  * IsLocalTableModification returns true if the table modified is a Postgres table.
  * We do not support recursive planning for MERGE yet, so we could have a join
