@@ -107,8 +107,12 @@ static AttrNumber FindResnoForVarInTargetList(List *targetList, int varno, int v
 static bool RelationInfoContainsOnlyRecurringTuples(PlannerInfo *plannerInfo,
 													Relids relids);
 static char * RecurringTypeDescription(RecurringTuplesType recurType);
-static DeferredErrorMessage * DeferredErrorIfUnsupportedLateralSubquery(
-	PlannerInfo *plannerInfo, Relids recurringRelIds, Relids nonRecurringRelIds);
+static DeferredErrorMessage * DeferredErrorIfUnsupportedLateralSubquery(PlannerInfo *
+																		plannerInfo,
+																		Relids
+																		recurringRelIds,
+																		Relids
+																		nonRecurringRelIds);
 static bool ContainsLateralSubquery(PlannerInfo *plannerInfo);
 static Var * PartitionColumnForPushedDownSubquery(Query *query);
 static bool ContainsReferencesToRelids(Query *query, Relids relids, int *foundRelid);
@@ -333,7 +337,9 @@ WhereOrHavingClauseContainsSubquery(Query *query)
 bool
 TargetListContainsSubquery(List *targetList)
 {
-	return FindNodeMatchingCheckFunction((Node *) targetList, IsNodeSubquery);
+	bool hasSubquery = FindNodeMatchingCheckFunction((Node *) targetList, IsNodeSubquery);
+
+	return hasSubquery;
 }
 
 
@@ -788,9 +794,9 @@ FromClauseRecurringTupleType(Query *queryTree)
  * such queries have lateral subqueries.
  */
 static DeferredErrorMessage *
-DeferredErrorIfUnsupportedRecurringTuplesJoin(
-	PlannerRestrictionContext *plannerRestrictionContext,
-	bool plannerPhase)
+DeferredErrorIfUnsupportedRecurringTuplesJoin(PlannerRestrictionContext *
+											  plannerRestrictionContext,
+											  bool plannerPhase)
 {
 	List *joinRestrictionList =
 		plannerRestrictionContext->joinRestrictionContext->joinRestrictionList;
@@ -1093,6 +1099,28 @@ DeferErrorIfCannotPushdownSubquery(Query *subqueryTree, bool outerMostQueryHasLi
 }
 
 
+/*
+ * FlattenGroupExprs flattens the GROUP BY expressions in the query tree
+ * by replacing VAR nodes referencing the GROUP range table with the actual
+ * GROUP BY expression. This is used by Citus planning to ensure correctness
+ * when analysing and building the distributed plan.
+ */
+void
+FlattenGroupExprs(Query *queryTree)
+{
+#if PG_VERSION_NUM >= PG_VERSION_18
+	if (queryTree->hasGroupRTE)
+	{
+		queryTree->targetList = (List *)
+								flatten_group_exprs(NULL, queryTree,
+													(Node *) queryTree->targetList);
+		queryTree->havingQual =
+			flatten_group_exprs(NULL, queryTree, queryTree->havingQual);
+	}
+#endif
+}
+
+
 /*
  * DeferErrorIfSubqueryRequiresMerge returns a deferred error if the subquery
  * requires a merge step on the coordinator (e.g. limit, group by non-distribution
@@ -1953,6 +1981,13 @@ static MultiNode *
 SubqueryPushdownMultiNodeTree(Query *originalQuery)
 {
 	Query *queryTree = copyObject(originalQuery);
+
+	/*
+	 * PG18+ need to flatten GROUP BY expressions to ensure correct processing
+	 * later on, such as identification of partition columns in GROUP BY.
+	 */
+	FlattenGroupExprs(queryTree);
+
 	List *targetEntryList = queryTree->targetList;
 	MultiCollect *subqueryCollectNode = CitusMakeNode(MultiCollect);
 
@@ -2023,13 +2058,13 @@ SubqueryPushdownMultiNodeTree(Query *originalQuery)
 	pushedDownQuery->targetList = subqueryTargetEntryList;
 	pushedDownQuery->jointree = copyObject(queryTree->jointree);
 	pushedDownQuery->rtable = copyObject(queryTree->rtable);
-#if PG_VERSION_NUM >= PG_VERSION_16
 	pushedDownQuery->rteperminfos = copyObject(queryTree->rteperminfos);
-#endif
 	pushedDownQuery->setOperations = copyObject(queryTree->setOperations);
 	pushedDownQuery->querySource = queryTree->querySource;
 	pushedDownQuery->hasSubLinks = queryTree->hasSubLinks;
-
+#if PG_VERSION_NUM >= PG_VERSION_18
+	pushedDownQuery->hasGroupRTE = queryTree->hasGroupRTE;
+#endif
 	MultiTable *subqueryNode = MultiSubqueryPushdownTable(pushedDownQuery);
 
 	SetChild((MultiUnaryNode *) subqueryCollectNode, (MultiNode *) subqueryNode);
@@ -2157,9 +2192,7 @@ CreateSubqueryTargetListAndAdjustVars(List *columnList)
 		 * the var - is empty. Otherwise, when given the query, the Postgres planner
 		 * may attempt to access a non-existent range table and segfault, as in #7787.
 		 */
-#if PG_VERSION_NUM >= PG_VERSION_16
 		column->varnullingrels = NULL;
-#endif
 	}
 
 	return subqueryTargetEntryList;
