@@ -1,12 +1,10 @@
-DROP FUNCTION pg_catalog.citus_add_rebalance_strategy;
 CREATE OR REPLACE FUNCTION pg_catalog.citus_add_rebalance_strategy(
     name name,
     shard_cost_function regproc,
     node_capacity_function regproc,
     shard_allowed_on_node_function regproc,
     default_threshold float4,
-    minimum_threshold float4 DEFAULT 0,
-    improvement_threshold float4 DEFAULT 0
+    minimum_threshold float4 DEFAULT 0
 )
     RETURNS VOID AS $$
     INSERT INTO
@@ -26,5 +24,5 @@ CREATE OR REPLACE FUNCTION pg_catalog.citus_add_rebalance_strategy(
             minimum_threshold
         );
     $$ LANGUAGE sql;
-COMMENT ON FUNCTION pg_catalog.citus_add_rebalance_strategy(name,regproc,regproc,regproc,float4, float4, float4)
+COMMENT ON FUNCTION pg_catalog.citus_add_rebalance_strategy(name,regproc,regproc,regproc,float4, float4)
   IS 'adds a new rebalance strategy which can be used when rebalancing shards or draining nodes';
