@@ -50,6 +50,8 @@ sub Usage()
     print "  --connection-timeout	Timeout for connecting to worker nodes\n";
     print "  --mitmproxy        	Start a mitmproxy for one of the workers\n";
     print "  --worker-count         Number of workers in Citus cluster (default: 2)\n";
+    print "  --citus-version        Citus version being tested (used for during extension create)\n";
+    print "  --citus-libdir         Absolute path to alternative Citus library directory\n";
     exit 1;
 }
 
@@ -87,6 +89,8 @@ my $conninfo = "";
 my $publicWorker1Host = "localhost";
 my $publicWorker2Host = "localhost";
 my $workerCount = 2;
+my $citusversion = "";
+my $citusLibdir = "";
 
 my $serversAreShutdown = "TRUE";
 my $usingWindows = 0;
@@ -121,6 +125,8 @@ GetOptions(
     'worker-1-public-hostname=s' => \$publicWorker1Host,
     'worker-2-public-hostname=s' => \$publicWorker2Host,
     'worker-count=i' => \$workerCount,
+    'citus-version=s' => \$citusversion,
+    'citus-libdir=s' => \$citusLibdir,
     'help' => sub { Usage() });
 
 my $fixopen = "$bindir/postgres.fixopen";
@@ -259,7 +265,7 @@ exec $valgrindPath \\
     --leak-check=no \\
     --error-markers=VALGRINDERROR-BEGIN,VALGRINDERROR-END \\
     --max-stackframe=16000000 \\
-    --log-file=$valgrindLogFile \\
+    --log-file=$valgrindLogFile.%p \\
     --fullpath-after=/ \\
     $bindir/postgres.orig \\
     "\$@"
@@ -307,6 +313,39 @@ sub generate_hba
     close $fh;
 }
 
+sub setup_symlink
+{
+    my ($originalfile, $targetfile) = @_;
+
+    # Only proceed if not on Windows and both files are defined and non-empty
+    return if $usingWindows;
+    return unless (defined $originalfile && $originalfile ne "");
+    return unless (defined $targetfile && $targetfile ne "");
+
+    -e $targetfile or die "Target is not found at $targetfile";
+    my $backup = $originalfile . ".bak";
+    rename($originalfile, $backup) or die "Failed to copy $originalfile to $backup: $!";
+
+    symlink($targetfile, $originalfile) or die "Failed to create symlink $originalfile -> $targetfile: $!";
+}
+
+sub restore_original
+{
+    my ($originalfile) = @_;
+
+    # Only proceed if not on Windows and file is defined and non-empty
+    return if $usingWindows;
+    return unless (defined $originalfile && $originalfile ne "");
+
+    my $backup = $originalfile . ".bak";
+
+    # Return silently if backup doesn't exist
+    return unless -e $backup;
+
+    unlink($originalfile) or die "Failed to remove symlink at $originalfile: $!";
+    rename($backup, $originalfile) or die "Failed to restore original file from $backup to $originalfile: $!";
+}
+
 # always want to call initdb under normal postgres, so revert from a
 # partial run, even if we're now not using valgrind.
 revert_replace_postgres();
@@ -590,6 +629,12 @@ if($isolationtester)
    push(@pgOptions, "citus.background_task_queue_interval=-1");
 }
 
+if($citusversion || $citusLibdir)
+{
+    push(@pgOptions, "citus.enable_version_checks=off");
+    push(@pgOptions, "columnar.enable_version_checks=off");
+}
+
 # Add externally added options last, so they overwrite the default ones above
 for my $option (@userPgOptions)
 {
@@ -774,6 +819,15 @@ if (!$conninfo)
 # Routine to shutdown servers at failure/exit
 sub ShutdownServers()
 {
+    my $saved_status = $?;
+
+    # Determine the actual PostgreSQL library directory for cleanup
+    my $psqlLibdir =`$pgConfig --pkglibdir`;
+    chomp $psqlLibdir;
+
+    restore_original(catfile($psqlLibdir, "citus.so")) if defined $psqlLibdir;
+    restore_original(catfile($psqlLibdir, "citus_columnar.so")) if defined $psqlLibdir;
+
     if (!$conninfo && $serversAreShutdown eq "FALSE")
     {
         system(catfile("$bindir", "pg_ctl"),
@@ -807,6 +861,9 @@ sub ShutdownServers()
         }
         $serversAreShutdown = "TRUE";
     }
+
+    # restore saved status
+    $? = $saved_status;
 }
 
 # setup the signal handler before we fork
@@ -857,7 +914,7 @@ if ($useMitmproxy)
   if ($mitmPid eq 0) {
     print("forked, about to exec mitmdump\n");
     setpgrp(0,0); # we're about to spawn both a shell and a mitmdump, kill them as a group
-    exec("mitmdump --rawtcp -p $mitmPort --mode reverse:localhost:57638 -s $regressdir/mitmscripts/fluent.py --set fifo=$mitmFifoPath --set flow_detail=0 --set termlog_verbosity=warn >proxy.output 2>&1");
+    exec("mitmdump --rawtcp -p $mitmPort --mode reverse:tcp://localhost:57638 -s $regressdir/mitmscripts/fluent.py --set fifo=$mitmFifoPath --set flow_detail=0 --set termlog_verbosity=warn --set connection_strategy=lazy >proxy.output 2>&1");
     die 'could not start mitmdump';
   }
 }
@@ -871,7 +928,9 @@ $SIG{__DIE__} = \&ShutdownServers;
 # Shutdown servers on exit only if help option is not used
 END
 {
-    if ($? != 1)
+    my $saved_status = $?;
+
+    if ($saved_status != 1)
     {
         ShutdownServers();
     }
@@ -881,6 +940,9 @@ END
     {
         revert_replace_postgres();
     }
+
+    # restore saved status
+    $? = $saved_status;
 }
 
 # want to use valgrind, replace binary before starting server
@@ -899,6 +961,18 @@ if ($followercluster && $backupnodetest == 0)
     $synchronousReplication = "-c synchronous_standby_names='FIRST 1 (*)' -c synchronous_commit=remote_apply";
 }
 
+# Ensure citus.so points to alternative library if provided
+if ($citusLibdir)
+{
+    print "Setting up symlinks to load citus extension libraries from alternative directory: $citusLibdir\n";
+    # Determine the actual PostgreSQL library directory
+    my $psqlLibdir =`$pgConfig --pkglibdir`;
+    chomp $psqlLibdir;
+
+    setup_symlink(catfile($psqlLibdir, "citus.so"), catfile($citusLibdir, "citus.so"));
+    setup_symlink(catfile($psqlLibdir, "citus_columnar.so"), catfile($citusLibdir, "citus_columnar.so"));
+}
+
 # Start servers
 if (!$conninfo)
 {
@@ -990,10 +1064,20 @@ if (!$conninfo)
 
         for my $extension (@extensions)
         {
-            system(catfile($bindir, "psql"),
-                ('-X', '-h', $host, '-p', $port, '-U', $user, "-d", "regression",
-                    '-c', "CREATE EXTENSION IF NOT EXISTS $extension;")) == 0
-                or die "Could not create extension $extension on worker port $port.";
+            if ($extension eq "citus" && $citusversion ne "")
+            {
+                system(catfile($bindir, "psql"),
+                    ('-X', '-h', $host, '-p', $port, '-U', $user, "-d", "regression",
+                        '-c', "CREATE EXTENSION IF NOT EXISTS $extension VERSION '$citusversion';")) == 0
+                    or die "Could not create extension $extension on worker port $port.";
+            }
+            else
+            {
+                system(catfile($bindir, "psql"),
+                    ('-X', '-h', $host, '-p', $port, '-U', $user, "-d", "regression",
+                        '-c', "CREATE EXTENSION IF NOT EXISTS $extension;")) == 0
+                    or die "Could not create extension $extension on worker port $port.";
+            }
         }
 
         foreach my $function (keys %functions)
