@@ -141,14 +141,21 @@ SELECT a FROM full_correlated WHERE a>200;
 $$
 );
 
-SELECT columnar_test_helpers.uses_custom_scan (
-$$
-SELECT a FROM full_correlated WHERE a=0 OR a=5;
-$$
-);
+
+BEGIN;
+  SET LOCAL enable_indexscan  TO 'OFF';
+  SET LOCAL enable_bitmapscan TO 'OFF';
+  SELECT columnar_test_helpers.uses_custom_scan (
+  $$
+  SELECT a FROM full_correlated WHERE a=0 OR a=5;
+  $$
+  );
+ROLLBACK;
 
 BEGIN;
   SET LOCAL columnar.enable_custom_scan TO 'OFF';
+  SET LOCAL enable_indexscan  TO 'OFF';
+  SET LOCAL enable_bitmapscan TO 'OFF';
   SELECT columnar_test_helpers.uses_seq_scan (
   $$
   SELECT a FROM full_correlated WHERE a=0 OR a=5;
@@ -361,12 +368,12 @@ CREATE INDEX uncorrelated_idx ON uncorrelated(x);
 ANALYZE correlated, uncorrelated;
 
 -- should choose chunk group filtering; selective and correlated
-EXPLAIN (analyze on, costs off, timing off, summary off)
+EXPLAIN (analyze on, costs off, timing off, summary off, BUFFERS OFF)
 SELECT * FROM correlated WHERE x = 78910;
 SELECT * FROM correlated WHERE x = 78910;
 
 -- should choose index scan; selective but uncorrelated
-EXPLAIN (analyze on, costs off, timing off, summary off)
+EXPLAIN (analyze off, costs off, timing off, summary off, BUFFERS OFF)
 SELECT * FROM uncorrelated WHERE x = 78910;
 SELECT * FROM uncorrelated WHERE x = 78910;
 
