@@ -1282,7 +1282,7 @@ WHEN NOT MATCHED THEN
   VALUES (s.some_number, 'parag');
 
 -- let's verify if data inserted to second shard of target.
-EXPLAIN (analyze on, costs off, timing off, summary off) SELECT * FROM target_table;
+EXPLAIN (analyze on, costs off, timing off, summary off, BUFFERS OFF) SELECT * FROM target_table;
 
 -- let's verify target data too.
 SELECT * FROM target_table;
@@ -1577,7 +1577,7 @@ SELECT create_distributed_table('target_json','id'), create_distributed_table('s
 -- single shard query given source_json is filtered and Postgres is smart to pushdown
 -- filter to the target_json as well
 SELECT public.coordinator_plan($Q$
-EXPLAIN (ANALYZE ON, TIMING OFF) MERGE INTO target_json sda
+EXPLAIN (ANALYZE ON, TIMING OFF, BUFFERS OFF) MERGE INTO target_json sda
 USING (SELECT * FROM source_json WHERE id = 1) sdn
 ON sda.id = sdn.id
 WHEN NOT matched THEN
@@ -1597,7 +1597,7 @@ SELECT * FROM target_json ORDER BY 1;
 
 -- join for source_json is happening at a different place
 SELECT public.coordinator_plan($Q$
-EXPLAIN (ANALYZE ON, TIMING OFF) MERGE INTO target_json sda
+EXPLAIN (ANALYZE ON, TIMING OFF, BUFFERS OFF) MERGE INTO target_json sda
 USING source_json s1 LEFT JOIN (SELECT * FROM source_json) s2 USING(z)
 ON sda.id = s1.id AND s1.id = s2.id
 WHEN NOT matched THEN
@@ -1607,7 +1607,7 @@ SELECT * FROM target_json ORDER BY 1;
 
 -- update JSON column
 SELECT public.coordinator_plan($Q$
-EXPLAIN (ANALYZE ON, TIMING OFF) MERGE INTO target_json sda
+EXPLAIN (ANALYZE ON, TIMING OFF, BUFFERS OFF) MERGE INTO target_json sda
 USING source_json sdn
 ON sda.id = sdn.id
 WHEN matched THEN
