@@ -1,3 +1,7 @@
+SET client_min_messages TO WARNING;
+CREATE EXTENSION IF NOT EXISTS citus_columnar;
+RESET client_min_messages;
+
 CREATE SCHEMA recurring_outer_join;
 SET search_path TO recurring_outer_join;
 
@@ -143,7 +147,7 @@ SELECT COUNT(*) FROM ref_1 LEFT JOIN (dist_1 t1 LEFT JOIN dist_1 t2 USING (a)) q
 
   SELECT COUNT(*) FROM dist_1 t1 FULL JOIN (dist_1 RIGHT JOIN citus_local_1 USING(a)) t2 USING (a);
 
-  -- subqury without FROM
+  -- subquery without FROM
   SELECT COUNT(*) FROM dist_1 t1 RIGHT JOIN (SELECT generate_series(1,10) AS a) t2 USING (a);
 
 -- such semi joins / anti joins are supported too
@@ -249,7 +253,7 @@ SELECT COUNT(*) FROM ref_1 LEFT JOIN (dist_1 t1 LEFT JOIN dist_1 t2 USING (a)) q
   ON (t1.a = t2.a)
   WHERE t1.a IN (SELECT a FROM dist_1 t3);
 
-  -- subqury without FROM
+  -- subquery without FROM
   SELECT COUNT(*) FROM
   (SELECT generate_series(1,10) AS a) t1
   JOIN dist_1 t2
@@ -292,8 +296,11 @@ LATERAL
     WHERE r1.a > dist_1.b
 ) as foo;
 
--- Qual is the same but top-level join is an anti-join. Right join
--- stays as is and hence requires recursive planning.
+-- Qual is the same but top-level join is an anti-join.
+-- The right join between t2 and t3 is pushed down.
+-- Citus determines that the whole query can be pushed down
+-- due to the equality constraint between two distributed
+-- tables t1 and t2.
 SELECT COUNT(*) FROM dist_1 t1
 WHERE NOT EXISTS (
     SELECT * FROM dist_1 t2
@@ -301,11 +308,17 @@ WHERE NOT EXISTS (
     WHERE t2.a = t1.a
 );
 
+SET client_min_messages TO DEBUG3;
+
 -- This time the semi-join qual is <t3.a = t1.a> (not <<t2.a = t1.a>)
 -- where t3 is the outer rel of the right join. Hence Postgres can't
--- replace right join with an inner join and so we recursively plan
--- inner side of the right join since the outer side is a recurring
--- rel.
+-- replace right join with an inner join.
+-- Citus pushes down the right join between t2 and t3 with constraints on
+-- the recurring outer part (t3). However, it cannnot push down the whole
+-- query as it can not establish an equivalence between the distribution
+-- tables t1 and t2. Hence, Citus tries to recursively plan the subquery.
+-- This attempt fails since the subquery has a reference to outer query.
+-- See #8113
 SELECT COUNT(*) FROM dist_1 t1
 WHERE EXISTS (
     SELECT * FROM dist_1 t2
@@ -320,6 +333,25 @@ WHERE NOT EXISTS (
     WHERE t3.a = t1.a
 );
 
+SET client_min_messages TO DEBUG1;
+
+-- Force recursive planning of the right join with offset
+SELECT COUNT(*) FROM dist_1 t1
+WHERE EXISTS (
+    SELECT * FROM dist_1 t2
+    RIGHT JOIN ref_1 t3 USING (a)
+    WHERE t3.a = t1.a
+    OFFSET 0
+);
+
+SELECT COUNT(*) FROM dist_1 t1
+WHERE NOT EXISTS (
+    SELECT * FROM dist_1 t2
+    RIGHT JOIN ref_1 t3 USING (a)
+    WHERE t3.a = t1.a
+    OFFSET 0
+);
+
 --
 -- more complex cases
 --
@@ -346,7 +378,8 @@ LEFT JOIN
 (
     dist_1 t4
     JOIN
-    -- 1) t6 is recursively planned since the outer side is recurring
+    -- 1) t6 is not recursively planned since it is
+    -- safe to push down the recurring outer side with constraints
     (SELECT t6.a FROM dist_1 t6 RIGHT JOIN ref_1 t7 USING(a)) t5
     USING(a)
 ) q
@@ -580,8 +613,8 @@ LEFT JOIN
 USING(a);
 
 -- cannot recursively plan because t3 (inner - distributed)
--- references t1 (outer - recurring)
-SELECT COUNT(*) FROM ref_1 t1 LEFT JOIN LATERAL (SELECT * FROM dist_1 t2 WHERE t1.b < t2.b) t3 USING (a);
+-- references t1 (outer - recurring over non-distribution column)
+SELECT COUNT(*) FROM ref_1 t1 LEFT JOIN LATERAL (SELECT * FROM dist_1 t2 WHERE t1.b < t2.b) t3 USING (b);
 SELECT COUNT(*) FROM (SELECT * FROM dist_1 OFFSET 100) t1 LEFT JOIN LATERAL (SELECT * FROM dist_1 t2 WHERE t1.b < t2.b) t3 USING (a);
 SELECT COUNT(*) FROM local_1 t1 LEFT JOIN LATERAL (SELECT * FROM dist_1 t2 WHERE t1.b < t2.b) t3 USING (a);
 SELECT COUNT(*) FROM (SELECT 1 a, generate_series(1,2) b) t1 LEFT JOIN LATERAL (SELECT * FROM dist_1 t2 WHERE t1.b < t2.b) t3 USING (a);
@@ -708,14 +741,13 @@ LEFT JOIN
 USING (a);
 
 SELECT COUNT(*) FROM ref_1 t1
--- 2) Since t8 is distributed and t1 is recurring, t8 needs be converted
---    to a recurring rel too. For this reason, subquery t8 is recursively
---    planned because t7 is recurring already.
+-- 2) It is also safe to push down this since the recurring outer side t1 and
+--    distributed inner side t8 are joined on the distribution column.
 LEFT JOIN
 (
     SELECT * FROM (SELECT * FROM ref_1 t2 RIGHT JOIN dist_1 t3 USING (a)) AS t4
     JOIN
-    -- 1) subquery t6 is recursively planned because t5 is recurring
+    -- 1) it is safe to push down subquery t7
     (SELECT * FROM ref_1 t5 LEFT JOIN (SELECT * FROM dist_2_columnar WHERE b < 150) t6 USING (a)) as t7
     USING(a)
 ) t8
@@ -724,14 +756,13 @@ USING (a);
 -- same test using a prepared statement
 PREPARE recurring_outer_join_p1 AS
 SELECT COUNT(*) FROM ref_1 t1
--- 2) Since t8 is distributed and t1 is recurring, t8 needs be converted
---    to a recurring rel too. For this reason, subquery t8 is recursively
---    planned because t7 is recurring already.
+-- 2) It is also safe to push down this since the recurring outer side t1 and
+--    distributed inner side t8 are joined on the distribution column.
 LEFT JOIN
 (
     SELECT * FROM (SELECT * FROM ref_1 t2 RIGHT JOIN dist_1 t3 USING (a)) AS t4
     JOIN
-    -- 1) subquery t6 is recursively planned because t5 is recurring
+    -- 1) it is safe to push down subquery t7
     (SELECT * FROM ref_1 t5 LEFT JOIN (SELECT * FROM dist_2_columnar WHERE b < $1) t6 USING (a)) as t7
     USING(a)
 ) t8
@@ -841,7 +872,7 @@ SELECT * FROM ref_1 t36 WHERE (b,100,a) IN (
     DISTINCT t31.b,
     -- 1) we first search for such joins in the target list and recursively plan t33
     --    because t32 is recurring
-    (SELECT max(b) FROM ref_1 t32 LEFT JOIN dist_1 t33 USING(a,b) WHERE t31.a = t32.a),
+    (SELECT max(b) FROM ref_1 t32 LEFT JOIN dist_1 t33 USING(b) WHERE t31.a = t32.a),
     (SELECT t34.a)
   FROM ref_1 t35
   LEFT JOIN dist_1 t31 USING (a,b)
@@ -958,10 +989,10 @@ BEGIN;
       SELECT t1.a, t1.b FROM ref_1 t1
       LEFT JOIN
       (
-          SELECT * FROM dist_1 t2 WHERE EXISTS (
+          SELECT DISTINCT ON (a) * FROM dist_1 t2 WHERE EXISTS (
               SELECT * FROM dist_1 t4
               WHERE t4.a = t2.a
-          )
+          ) ORDER BY a, b
       ) t3
       USING (a)
   ) q
@@ -986,7 +1017,7 @@ BEGIN;
   RETURNING *;
 ROLLBACK;
 
--- INSERT .. SELECT: pull to coordinator
+-- INSERT .. SELECT: Repartitioned
 BEGIN;
   DELETE FROM ref_1 WHERE a IS NULL;
 
@@ -997,6 +1028,17 @@ BEGIN;
   ON (t1.a = t2.a);
 ROLLBACK;
 
+-- INSERT .. SELECT: pull to coordinator
+BEGIN;
+  DELETE FROM ref_1 WHERE a IS NULL;
+
+  INSERT INTO dist_1
+  SELECT t1.*
+  FROM ref_1 t1
+  LEFT JOIN dist_1 t2
+  ON (t1.b = t2.b);
+ROLLBACK;
+
 -- INSERT .. SELECT: repartitioned (due to <t1.a*3>)
 BEGIN;
   INSERT INTO dist_1
@@ -1020,3 +1062,6 @@ ROLLBACK;
 
 SET client_min_messages TO ERROR;
 DROP SCHEMA recurring_outer_join CASCADE;
+
+SET client_min_messages TO WARNING;
+DROP EXTENSION citus_columnar CASCADE;
